@@ -2,7 +2,8 @@ import React from "react";
 import { useCallback, useEffect, useState } from "react";
 
 import {
-    apiFetchLH2CalibrationState, apiApplyLH2Calibration, apiAddLH2CalibrationPoint
+    apiFetchLH2CalibrationState, apiApplyLH2Calibration,
+    apiAddLH2CalibrationPoint, inactiveAddress
 } from "./rest";
 
 const referencePoints = [
@@ -13,6 +14,8 @@ const referencePoints = [
 ]
 
 const DotBotsMapPoint = (props) => {
+  const [hovered, setHovered ] = useState(false);
+
   let rgbColor = "rgb(0, 0, 0)"
   if (props.dotbot.rgb_led) {
     rgbColor = `rgb(${props.dotbot.rgb_led.red}, ${props.dotbot.rgb_led.green}, ${props.dotbot.rgb_led.blue})`
@@ -21,18 +24,44 @@ const DotBotsMapPoint = (props) => {
   const posX = props.mapSize * parseFloat(props.dotbot.lh2_position.x);
   const posY = props.mapSize * parseFloat(props.dotbot.lh2_position.y);
 
+  const onMouseEnter = () => {
+    if (props.dotbot.status !== 0) {
+      return;
+    }
+
+    setHovered(true);
+  };
+
+  const onMouseLeave = () => {
+    setHovered(false);
+  };
+
   return (
     <>
     { (props.dotbot.address === props.active) &&
       <circle cx={posX} cy={posY} r="8" stroke="black" strokeWidth="2" fill="none" />
     }
-    <circle cx={posX} cy={posY} r={props.dotbot.address === props.active ? 8: 5} opacity={`${props.dotbot.status === 0 ? "80%" : "20%"}`} fill={rgbColor}><title>{`${props.dotbot.address}@${posX}x${posY}`}</title></circle>
+    <circle cx={posX} cy={posY}
+        r={(props.dotbot.address === props.active || hovered) ? 8: 5}
+        opacity={`${props.dotbot.status === 0 ? "80%" : "20%"}`}
+        fill={rgbColor}
+        style={{ cursor: "pointer" }}
+        onClick={
+          () => {
+            props.updateActive(props.dotbot.address === props.active ? inactiveAddress : props.dotbot.address)
+          }
+        }
+        onMouseEnter={onMouseEnter}
+        onMouseLeave={onMouseLeave} >
+      <title>{`${props.dotbot.address}@${posX}x${posY}`}</title>
+    </circle>
     </>
   )
 }
 
 export const DotBotsMap = (props) => {
 
+  const [ displayGrid, setDisplayGrid ] = useState(true);
   const [ calibrationFetched, setCalibrationFetched ] = useState(false);
   const [ calibrationState, setCalibrationState ] = useState("unknown");
   const [ pointsChecked, setPointsChecked ] = useState([false, false, false, false]);
@@ -65,6 +94,10 @@ export const DotBotsMap = (props) => {
     return mapSize * (coordinate + 0.5) - 5;
   };
 
+  const updateDisplayGrid = (event) => {
+    setDisplayGrid(event.target.checked);
+  };
+
   useEffect(() => {
     if (!calibrationFetched) {
       fetchCalibrationState();
@@ -97,28 +130,28 @@ export const DotBotsMap = (props) => {
           <div style={{ height: gridSize, width: gridSize }}>
             <svg style={{ height: gridSize, width: gridSize }}>
               <defs>
-                <pattern id="smallGrid" width={`${mapSize / 50}`} height={`${mapSize / 50}`} patternUnits="userSpaceOnUse">
+                <pattern id={`smallGrid${mapSize}`} width={`${mapSize / 50}`} height={`${mapSize / 50}`} patternUnits="userSpaceOnUse">
                   <path d={`M ${mapSize / 50} 0 L 0 0 0 ${mapSize / 50}`} fill="none" stroke="gray" strokeWidth="0.5"/>
                 </pattern>
-                <pattern id="grid" width={`${mapSize / 5}`} height={`${mapSize / 5}`} patternUnits="userSpaceOnUse">
-                  <rect width={`${mapSize / 5}`} height={`${mapSize / 5}`} fill="url(#smallGrid)"/>
+                <pattern id={`grid${mapSize}`} width={`${mapSize / 5}`} height={`${mapSize / 5}`} patternUnits="userSpaceOnUse">
+                  <rect width={`${mapSize / 5}`} height={`${mapSize / 5}`} fill={`url(#smallGrid${mapSize})`}/>
                   <path d={`M ${mapSize / 5} 0 L 0 0 0 ${mapSize / 5}`} fill="none" stroke="gray" strokeWidth="1"/>
                 </pattern>
               </defs>
               {/* Map grid */}
-              <rect width="100%" height="100%" fill="url(#grid)" />
+              <rect width="100%" height="100%" fill={displayGrid ? `url(#grid${mapSize})`: "none"} stroke="gray" strokeWidth="1"/>
               {/* DotBots points */}
               {
                 props.dotbots && props.dotbots
                   .filter(dotbot => dotbot.lh2_position)
                   .filter(dotbot => dotbot.status !== 2)
-                  .map(dotbot => <DotBotsMapPoint key={dotbot.address} dotbot={dotbot} active={props.active} mapSize={props.mapSize} />)
+                  .map(dotbot => <DotBotsMapPoint key={dotbot.address} dotbot={dotbot} active={props.active} updateActive={props.updateActive} mapSize={props.mapSize} />)
               }
               {
                 ["running", "ready"].includes(calibrationState) && (
                   <>
                   {referencePoints.map((point, index) => (
-                    <><rect key={index} x={coordinateToPixel(point.x)} y={coordinateToPixel(point.y * -1)} width="10" height="10" fill={pointsChecked[index] ? "green" : "grey"} onClick={() => pointClicked(index)}><title>{index + 1}</title></rect></>
+                    <rect key={index} x={coordinateToPixel(point.x)} y={coordinateToPixel(point.y * -1)} width="10" height="10" fill={pointsChecked[index] ? "green" : "grey"} style={{ cursor: "pointer" }} onClick={() => pointClicked(index)}><title>{index + 1}</title></rect>
                   ))}
                   </>
                 )
@@ -127,19 +160,28 @@ export const DotBotsMap = (props) => {
           </div>
         </div>
       </div>
-      <div className="row">
-        <div className="col d-flex justify-content-center">
-          <button className={`btn btn-sm m-1 ${calibrationButtonClass}`} onClick={calibrateClicked}>{calibrationButtonLabel}</button>
+      <div className="card m-1">
+        <div className="card-header">Map settings</div>
+        <div className="card-body">
+          <div className="d-flex mb-2">
+            <div className="form-check">
+              <input className="form-check-input" type="checkbox" id="flexCheckDisplayGrid" defaultChecked={displayGrid} onChange={updateDisplayGrid} />
+              <label className="form-check-label" htmlFor="flexCheckDisplayGrid">Display grid</label>
+            </div>
+          </div>
+          <div className="d-flex">
+            <button className={`btn btn-sm ${calibrationButtonClass}`} onClick={calibrateClicked}>{calibrationButtonLabel}</button>
+          </div>
+          {calibrationState === "running" && (
+          <div className="d-flex">
+            <p style={{ width: calibrationTextWidth }}>
+              Place a DotBot on the marks on the ground and once done, click the corresponding rectangle on the grid. Repeat the operation for each marks.
+              Once all rectangles are green, click "Apply calibration".
+            </p>
+          </div>
+          )}
         </div>
       </div>
-      {calibrationState === "running" && (
-      <div className="d-flex justify-content-center">
-        <p className="text-center" style={{ width: calibrationTextWidth }}>
-          Place a DotBot on the marks on the ground and once done, click the corresponding rectangle on the grid. Repeat the operation for each marks.
-          Once all rectangles are green, click "Apply calibration".
-        </p>
-      </div>
-      )}
     </div>
   )
 }
