@@ -5,6 +5,8 @@ from enum import Enum
 from typing import Optional
 from pydantic import BaseModel
 
+from dotbot.protocol import ApplicationType
+
 
 class DotBotAddressModel(BaseModel):
     """Simple model to hold a DotBot address."""
@@ -43,6 +45,13 @@ class DotBotLH2Position(BaseModel):
     z: float
 
 
+class DotBotGPSPosition(BaseModel):
+    """GPS position of a DotBot, usually running a SailBot application."""
+
+    latitude: float
+    longitude: float
+
+
 class DotBotStatus(int, Enum):
     """Status of a DotBot."""
 
@@ -55,10 +64,11 @@ class DotBotModel(BaseModel):
     """Model class that defines a DotBot."""
 
     address: str
-    application: str = "DotBot"
+    application: ApplicationType = ApplicationType.DotBot
     swarm: str = "0000"
     status: DotBotStatus = DotBotStatus.ALIVE
     last_seen: float
     move_raw: Optional[DotBotMoveRawCommandModel]
     rgb_led: Optional[DotBotRgbLedCommandModel]
     lh2_position: Optional[DotBotLH2Position]
+    gps_position: Optional[DotBotGPSPosition]
